@@ -1,6 +1,6 @@
 "arrow.plot" <-
 function (a1, a2, u = NA, v = NA, arrow.ex = 0.05, 
-     xpd = TRUE, true.angle = FALSE, ...) 
+     xpd = TRUE, true.angle = FALSE, arrowfun=arrows,...) 
 {
     if (is.matrix(a1)) {
         x <- a1[, 1]
@@ -33,6 +33,6 @@ function (a1, a2, u = NA, v = NA, arrow.ex = 0.05,
     invisible()
     old.xpd <- par()$xpd
     par(xpd = xpd)
-    arrows(x, y, x + u, y + v, ...)
+    arrowfun(x, y, x + u, y + v, ...)
     par(xpd = old.xpd)
 }
