@@ -1,13 +1,12 @@
 "surface.Krig" <-
 function(obj, grid.list = NA, extrap = FALSE, graphics.reset = NULL, xlab = NULL,
 	ylab = NULL, main = NULL, zlab = NULL, zlim = NULL, levels = NULL,
-	type = "C", nx=80, ny=80, ...)
+	type = "C", nx=80, ny=80,...)
 {
 	## modified so that you can give main, and ylab as arguments
 	## in ... and have them passed correctly
 	out.p <- predict.surface(obj, 
-             grid.list = grid.list, extrap = extrap, 
-               nx=nx,ny=ny, drop.Z=TRUE)
+             grid.list = grid.list, extrap = extrap, nx=nx,ny=ny)
 	if(!is.null(ylab))
 		out.p$ylab <- ylab
 	if(!is.null(xlab))
